@@ -15,6 +15,10 @@
    along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
 
+#ifdef PS2_EE
+#include "ps2_compat.h"
+#endif
+
 #ifdef WIN32
 #include <win32/win32_compat.h>
 #else
